Patch "selftests/bpf: Fix fill_link_info selftest on powerpc" has been added to the 6.13-stable tree

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



This is a note to let you know that I've just added the patch titled

    selftests/bpf: Fix fill_link_info selftest on powerpc

to the 6.13-stable tree which can be found at:
    http://www.kernel.org/git/?p=linux/kernel/git/stable/stable-queue.git;a=summary

The filename of the patch is:
     selftests-bpf-fix-fill_link_info-selftest-on-powerpc.patch
and it can be found in the queue-6.13 subdirectory.

If you, or anyone else, feels it should not be added to the stable tree,
please let <stable@xxxxxxxxxxxxxxx> know about it.



commit 99ba4bd94f10806a6324aa8b6aa7f1501dba8616
Author: Saket Kumar Bhaskar <skb99@xxxxxxxxxxxxx>
Date:   Mon Dec 9 12:27:20 2024 +0530

    selftests/bpf: Fix fill_link_info selftest on powerpc
    
    [ Upstream commit 4d33dc1bc31df80356c49e40dbd3ddff19500bcb ]
    
    With CONFIG_KPROBES_ON_FTRACE enabled on powerpc, ftrace_location_range
    returns ftrace location for bpf_fentry_test1 at offset of 4 bytes from
    function entry. This is because branch to _mcount function is at offset
    of 4 bytes in function profile sequence.
    
    To fix this, add entry_offset of 4 bytes while verifying the address for
    kprobe entry address of bpf_fentry_test1 in verify_perf_link_info in
    selftest, when CONFIG_KPROBES_ON_FTRACE is enabled.
    
    Disassemble of bpf_fentry_test1:
    
    c000000000e4b080 <bpf_fentry_test1>:
    c000000000e4b080:       a6 02 08 7c     mflr    r0
    c000000000e4b084:       b9 e2 22 4b     bl      c00000000007933c <_mcount>
    c000000000e4b088:       01 00 63 38     addi    r3,r3,1
    c000000000e4b08c:       b4 07 63 7c     extsw   r3,r3
    c000000000e4b090:       20 00 80 4e     blr
    
    When CONFIG_PPC_FTRACE_OUT_OF_LINE [1] is enabled, these function profile
    sequence is moved out of line with an unconditional branch at offset 0.
    So, the test works without altering the offset for
    'CONFIG_KPROBES_ON_FTRACE && CONFIG_PPC_FTRACE_OUT_OF_LINE' case.
    
    Disassemble of bpf_fentry_test1:
    
    c000000000f95190 <bpf_fentry_test1>:
    c000000000f95190:       00 00 00 60     nop
    c000000000f95194:       01 00 63 38     addi    r3,r3,1
    c000000000f95198:       b4 07 63 7c     extsw   r3,r3
    c000000000f9519c:       20 00 80 4e     blr
    
    [1] https://lore.kernel.org/all/20241030070850.1361304-13-hbathini@xxxxxxxxxxxxx/
    
    Fixes: 23cf7aa539dc ("selftests/bpf: Add selftest for fill_link_info")
    Signed-off-by: Saket Kumar Bhaskar <skb99@xxxxxxxxxxxxx>
    Signed-off-by: Andrii Nakryiko <andrii@xxxxxxxxxx>
    Link: https://lore.kernel.org/bpf/20241209065720.234344-1-skb99@xxxxxxxxxxxxx
    Signed-off-by: Sasha Levin <sashal@xxxxxxxxxx>

diff --git a/tools/testing/selftests/bpf/prog_tests/fill_link_info.c b/tools/testing/selftests/bpf/prog_tests/fill_link_info.c
index d50cbd8040d45..e59af2aa66016 100644
--- a/tools/testing/selftests/bpf/prog_tests/fill_link_info.c
+++ b/tools/testing/selftests/bpf/prog_tests/fill_link_info.c
@@ -171,6 +171,10 @@ static void test_kprobe_fill_link_info(struct test_fill_link_info *skel,
 		/* See also arch_adjust_kprobe_addr(). */
 		if (skel->kconfig->CONFIG_X86_KERNEL_IBT)
 			entry_offset = 4;
+		if (skel->kconfig->CONFIG_PPC64 &&
+		    skel->kconfig->CONFIG_KPROBES_ON_FTRACE &&
+		    !skel->kconfig->CONFIG_PPC_FTRACE_OUT_OF_LINE)
+			entry_offset = 4;
 		err = verify_perf_link_info(link_fd, type, kprobe_addr, 0, entry_offset);
 		ASSERT_OK(err, "verify_perf_link_info");
 	} else {
diff --git a/tools/testing/selftests/bpf/progs/test_fill_link_info.c b/tools/testing/selftests/bpf/progs/test_fill_link_info.c
index 6afa834756e9f..fac33a14f2009 100644
--- a/tools/testing/selftests/bpf/progs/test_fill_link_info.c
+++ b/tools/testing/selftests/bpf/progs/test_fill_link_info.c
@@ -6,13 +6,20 @@
 #include <stdbool.h>
 
 extern bool CONFIG_X86_KERNEL_IBT __kconfig __weak;
+extern bool CONFIG_PPC_FTRACE_OUT_OF_LINE __kconfig __weak;
+extern bool CONFIG_KPROBES_ON_FTRACE __kconfig __weak;
+extern bool CONFIG_PPC64 __kconfig __weak;
 
 /* This function is here to have CONFIG_X86_KERNEL_IBT
  * used and added to object BTF.
  */
 int unused(void)
 {
-	return CONFIG_X86_KERNEL_IBT ? 0 : 1;
+	return CONFIG_X86_KERNEL_IBT ||
+			CONFIG_PPC_FTRACE_OUT_OF_LINE ||
+			CONFIG_KPROBES_ON_FTRACE ||
+			CONFIG_PPC64 ? 0 : 1;
 }
 
 SEC("kprobe")
@@ -6,13 +6,20 @@
 
-/* This function is here to have CONFIG_X86_KERNEL_IBT
- * used and added to object BTF.
+/* This function is here to have CONFIG_X86_KERNEL_IBT,
+ * CONFIG_PPC_FTRACE_OUT_OF_LINE, CONFIG_KPROBES_ON_FTRACE,
+ * CONFIG_PPC6 used and added to object BTF.
  */
 int unused(void)




[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[Index of Archives]     [Linux USB Devel]     [Linux Audio Users]     [Yosemite News]     [Linux Kernel]     [Linux SCSI]

  Powered by Linux